

/*
Voter Response to Peak and End Transfers: Evidence from a Conditional Cash Transfer Experiment
Sebastian Galiani, Nadya Hajj, Patrick J. McEwan, Pablo Ibarrarán, and Nandita Krishnaswamy
American Economic Journal: Economic Policy

Final code: November 1, 2018
Email pmcewan@wellesley.edu with questions or comments.
*/

clear all
set more off
cd ".../20170448_data" // Update user directory
use bono10000

drop if share_p_participation==0 // Drop single outlier (see text for explanation) with zero valid votes

* Table 1: Number of villages in the main and restricted estimation samples
	* treatment:  CCT1=1, CCT=2, CCT=3
	tab treatment // Main estimation sample
	tab treatment if sampleflag==1 // Flag of restricted estimation sample

* Table 2: Baseline characteristics of villages in the main estimation sample
* Online appendix Table B1: Baseline characteristics of villages in the restricted estimation sample
	preserve
	gl vars "share_p_nacional_2009 share_p_liberal_2009 female age lenca school literate work dirtfloor pipedwater electriclight sewerseptic"
	keep $vars treatment sampleflag
	order $vars treatment  sampleflag
	bys treatment: outreg2 using "table_2",sum(log) eqkeep(mean sd N) replace // need to install user-written outreg2
	keep if sampleflag==1
	bys treatment: outreg2 using "table_b1",sum(log) eqkeep(mean sd N) replace
	restore
	
	* p-values
	foreach v in $vars {
		reg `v' CCT1 CCT2,robust
		test CCT1=CCT2=0
		}
	foreach v in $vars {
		display "`v'"
		ksmirnov `v' if CCT1==1 | CCT3==1,by(treatment)
		ksmirnov `v' if CCT2==1 | CCT3==1,by(treatment)
		}
	foreach v in $vars {
		reg `v' CCT1 CCT2 if sampleflag==1,robust
		test CCT1=CCT2=0
		}
	foreach v in $vars {
		display "`v'"
		ksmirnov `v' if sampleflag==1 & (CCT1==1 | CCT3==1),by(treatment)
		ksmirnov `v' if sampleflag==1 & (CCT2==1 | CCT3==1),by(treatment)
		}

* Table 3: Effects on turnout and incumbent party vote share in the 2013 presidential election	
	gl type "participation nacional"
	outreg,clear(s1)
	outreg,clear(s2)
	foreach v in $type {
		reg share_p_`v' CCT1 CCT2, robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			sum share_p_`v' if CCT3==1 
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s1) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p')
		reg share_p_`v' CCT1 CCT2 $vars, robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			sum share_p_`v' if CCT3==1
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s1) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p')
		reg share_p_`v' CCT1 CCT2 if sampleflag==1, robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			sum share_p_`v' if CCT3==1 & sampleflag==1
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s2) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p') 
		reg share_p_`v' CCT1 CCT2 $vars if sampleflag==1, robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			sum share_p_`v' if CCT3==1 & sampleflag==1
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s2) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p') 
		}
	outreg using table_3, replay(s1) replace basefont(fs10) landscape title("Panel A: Main Sample)")
	outreg using table_3, replay(s2) addtable basefont(fs10) title("Panel B: Restricted Sample)")

* Table 4: Effects on other parties' vote shares in the 2013 presidential election	
	gl type "liberal libertad anticorrupcion"
	outreg,clear(s1)
	outreg,clear(s2)
	foreach v in $type {
		reg share_p_`v' CCT1 CCT2, robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			sum share_p_`v' if CCT3==1 
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s1) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p') 
		reg share_p_`v' CCT1 CCT2 $vars, robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			sum share_p_`v' if CCT3==1
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s1) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p') 
		reg share_p_`v' CCT1 CCT2 if sampleflag==1, robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			sum share_p_`v' if CCT3==1 & sampleflag==1
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s2) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p') 
		reg share_p_`v' CCT1 CCT2 $vars if sampleflag==1, robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			sum share_p_`v' if CCT3==1 & sampleflag==1
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s2) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p') 
		}
	outreg using table_4, replay(s1) replace basefont(fs10) title("Panel A: Main Sample")
	outreg using table_4, replay(s2) addtable basefont(fs10) title("Panel B: Restricted Sample")

/* See read-me file
* Table 5: Effects on transfers per registered voter
	gl type "paytotal peak end peakend"
	outreg,clear(s1)
	outreg,clear(s2)
	foreach v in $type {
		reg `v' CCT1 CCT2, robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			test CCT1=CCT2=0
			local F : display %4.0f r(F)
			sum `v' if CCT3==1 
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s1) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p'\"F (CCT1=CCT2=0)",`F')
		reg `v' CCT1 CCT2 $vars, robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			test CCT1=CCT2=0
			local F : display %4.0f r(F)
			sum `v' if CCT3==1 
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s1) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p'\"F (CCT1=CCT2=0)",`F')
		reg `v' CCT1 CCT2 if sampleflag==1, robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			test CCT1=CCT2=0
			local F : display %4.0f r(F)
			sum `v' if CCT3==1 & sampleflag==1
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s2) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p'\"F (CCT1=CCT2=0)",`F') 
		reg `v' CCT1 CCT2 $vars if sampleflag==1, robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			test CCT1=CCT2=0
			local F : display %4.0f r(F)
			sum `v' if CCT3==1 & sampleflag==1
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s2) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p'\"F (CCT1=CCT2=0)",`F') 
		}
	outreg using table_5, replay(s1) replace basefont(fs10) landscape title("Panel A: Main Sample")
	outreg using table_5, replay(s2) addtable basefont(fs10) title("Panel B: Restricted Sample")

* Table 6: Two-stage least squares regressions of the effects of transfers on turnout and incumbent vote share
	gl type "participation nacional"
	outreg,clear(s1)
	outreg,clear(s2)
	foreach v in $type {
		ivregress 2sls share_p_`v' (paytotal peakend = CCT1 CCT2) $vars, robust first
			test paytotal=peakend
			local p : display %4.2f r(p)	
			outreg, keep(paytotal peakend) merge(s1) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("p-value",`p')
		ivregress 2sls share_p_`v' (paytotal peak = CCT1 CCT2) $vars, robust 
			test paytotal=peak
			local p : display %4.2f r(p)	
			outreg, keep(paytotal peak) merge(s1) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("p-value",`p')
		ivregress 2sls share_p_`v' (paytotal end = CCT1 CCT2) $vars, robust
			test paytotal=end
			local p : display %4.2f r(p)	
			outreg, keep(paytotal end) merge(s1) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("p-value",`p')
		ivregress 2sls share_p_`v' (paytotal peakend = CCT1 CCT2) $vars if sampleflag==1, robust
			test paytotal=peakend
			local p : display %4.2f r(p)	
			outreg, keep(paytotal peakend) merge(s2) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N")  addrows("p-value",`p')
		ivregress 2sls share_p_`v' (paytotal peak = CCT1 CCT2) $vars if sampleflag==1, robust
			test paytotal=peak
			local p : display %4.2f r(p)	
			outreg, keep(paytotal peak) merge(s2) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("p-value",`p')
		ivregress 2sls share_p_`v' (paytotal end = CCT1 CCT2) $vars if sampleflag==1, robust
			test paytotal=end
			local p : display %4.2f r(p)	
			outreg, keep(paytotal end) merge(s2) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("p-value",`p')
	}
	outreg using table_6, replay(s1) replace basefont(fs10) landscape title("Panel A: Main Sample")
	outreg using table_6, replay(s2) addtable basefont(fs10) title("Panel B: Restricted Sample")
*/

/* See readme file
* Figures 1, 2, and 3
	preserve
	use figures_1_2_3,clear
	local l1=wofd(d(15aug2011))
	local l2=wofd(d(9sep2011))
	local b1=wofd(d(2jan2012)) 
	local b2=wofd(d(18jun2012)) 
	local b3=(`b1'+`b2')/2
	local f1=wofd(d(1mar2013)) 
	local f2=wofd(d(23jun2013)) 
	local f3=(`f1'+`f2')/2
	local election=wofd(d(23nov2013)) 
	egen avg=mean(monto_total_pagado),by(treatment week)
	by week treatment,s: gen avg2=avg if _n==1
	twoway (histogram week if treatment==1, yaxis(2) color(gs12)  discrete freq yti("", axis(2)) yscale(range(0 6851.6) axis(2)) ylab(, axis(2)) yti("Fraction of transfers in CCT1", axis(2)) ylab(0 "0" 8687.5 ".1" 17375 ".2",labsize(medsmall) axis(2))) ///
		   (histogram week if endpayment==1 & treatment==1,yaxis(2) color(gs3) discrete freq ylab(,axis(2)) yscale(axis(2)) ylab(, axis(2)) yti("Fraction of transfers in CCT1", axis(2))) ///
		   (scatter avg2 week if treatment==1, msym(circle_hollow) mcolor(gs3) yaxis(1) yscale(range(0 8000) axis(1)) yti("Average transfer (Lps.)", axis(1)) ylab(0 2500 5000 7500 ,labsize(medsmall) axis(1)) ///
					), ///
		   legend(off) xti("")  xscale(range(`l1' `election')) xlab(`l2' `b1' `b2' `f1' `f2' `election' ,labsize(small)) xline(`l2' `b1' `b2' `f1' `f2' `election',lp(dot)) ///
		   name(daily1,replace) xti("Week") ///
			text(8000 `l2' "Randomization", placement(sw) orientation(vertical) size(small)) ///
			text(8000 `election' "Election", placement(sw) orientation(vertical) size(small)) ///
			text(8000 `b3' "Baseline surveys" "in CCT1 and CCT2", placement(s) size(vsmall)) ///
			text(8000 `f3' "Follow-up surveys" "in CCT1 and CCT2", placement(s) size(vsmall)) 

	twoway (histogram week if treatment==2, yaxis(2) color(gs12)  discrete freq yti("", axis(2)) yscale(range(0 6851.6) axis(2)) ylab(, axis(2)) yti("Fraction of transfers in CCT2", axis(2)) ylab(0 "0" 3425.8 ".1" 6851.6 ".2",labsize(medsmall) axis(2))) ///
		   (histogram week if endpayment==1 & treatment==2,yaxis(2) color(gs3) discrete freq ylab(,axis(2)) yscale(axis(2)) ylab(, axis(2)) yti("Fraction of transfers in CCT2", axis(2))) ///
		   (scatter avg2 week if treatment==2, msym(circle_hollow) mcolor(gs3) yaxis(1) yscale(range(0 8000) axis(1)) yti("Average transfer (Lps.)", axis(1)) ylab(0 2500 5000 7500 ,labsize(medsmall) axis(1)) ///
					), ///
		   legend(off) xti("")  xscale(range(`l1' `election')) xlab(`l2' `b1' `b2' `f1' `f2' `election' ,labsize(small)) xline(`l2' `b1' `b2' `f1' `f2' `election',lp(dot)) ///
		   name(daily2,replace)  xti("Week") ///
			text(8000 `l2' "Randomization", placement(sw) orientation(vertical) size(small)) ///
			text(8000 `election' "Election", placement(sw) orientation(vertical) size(small)) ///
			text(8000 `b3' "Baseline surveys" "in CCT1 and CCT2", placement(s) size(vsmall)) ///
			text(8000 `f3' "Follow-up surveys" "in CCT1 and CCT2", placement(s) size(vsmall)) 

	twoway (histogram week if treatment==3, yaxis(2) color(gs12)  discrete freq yti("", axis(2)) yscale(range(0 6851.6) axis(2)) ylab(, axis(2)) yti("Fraction of transfers in CCT3", axis(2)) ylab(0 "0" 13904.9 ".1" 27809.8 ".2",labsize(medsmall) axis(2))) ///
		   (histogram week if endpayment==1 & treatment==3,yaxis(2) color(gs3) discrete freq ylab(,axis(2)) yscale(axis(2)) ylab(, axis(2)) yti("Fraction of transfers in CCT3", axis(2))) ///
		   (scatter avg2 week if treatment==3, msym(circle_hollow) mcolor(gs3) yaxis(1) yscale(range(0 8000) axis(1)) yti("Average transfer (Lps.)", axis(1)) ylab(0 2500 5000 7500 ,labsize(medsmall) axis(1)) ///
					), ///
		   legend(off) xti("")  xscale(range(`l1' `election')) xlab(`l2' `b1' `b2' `f1' `f2' `election' ,labsize(small)) xline(`l2' `b1' `b2' `f1' `f2' `election',lp(dot)) ///
		   name(daily3,replace)  xti("Week") ///
			text(8000 `l2' "Randomization", placement(sw) orientation(vertical) size(small)) ///
			text(8000 `election' "Election", placement(sw) orientation(vertical) size(small)) ///
			text(8000 `b3' "Baseline surveys" "in CCT1 and CCT2", placement(s) size(vsmall)) ///
			text(8000 `f3' "Follow-up surveys" "in CCT1 and CCT2", placement(s) size(vsmall)) 

* Figure 4: Cumulative transfers per registered voter in CCT1, CCT2, and CCT3
	use figure_4,clear
 	collapse (mean) montopc,by(week treatment)
	reshape wide montopc ,i(week) j(treatment)
	scatter montopc1 montopc2 montopc3 week, ylab(0 1000 2000 3000) yscale(range(0 3500)) msym(i i i) c(l l l) lp(dash longdash solid) legend(order(1 2 3) cols(3) label(1 "CCT1") label(2 "CCT2") label(3 "CCT3")) xti("") yti("Transfers per registered voter (Lps.)") xlab(`l2' `b1' `b2' `f1' `f2' `election',labsize(small) ) xline(`l2' `b1' `b2' `f1' `f2' `election',lp(dot)) ///
			xti("Week") ///
			text(3500 `l2' "Randomization", placement(sw) orientation(vertical) size(small)) ///
			text(3500 `election' "Election", placement(sw) orientation(vertical) size(small)) ///
			text(3500 `b3' "Baseline surveys" "in CCT1 and CCT2", placement(s) size(vsmall)) ///
			text(3500 `f3' "Follow-up surveys" "in CCT1 and CCT2", placement(s) size(vsmall)) ///
			name(montopc,replace)
	restore
*/

* Online appendix Table A1: see separate .do file (dhs.do)
* Online appendix Table A2: see separate .do file (dhs.do)
* Online appendix Table B1: see code above
	
* Online appendix Table C1: Heterogeneous effects on turnout and incumbent party vote share in 2013 presidential election
	egen zcarga=std(carga)
	gen CCT1xc=  (zcarga)*CCT1
	gen CCT2xc=  (zcarga)*CCT2
	egen zcarga2=std(carga) if sampleflag==1
	gen CCT1xc_r=  (zcarga2)*CCT1
	gen CCT2xc_r=  (zcarga2)*CCT2

	gl type "participation nacional"
	outreg,clear(s1)
	outreg,clear(s2)
	foreach v in $type {
		reg share_p_`v' CCT1 CCT1xc CCT2 CCT2xc $vars zcarga, robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			sum share_p_`v' if CCT3==1
			local m : display %5.1f `r(mean)'			
			outreg, keep( CCT1 CCT1xc CCT2 CCT2xc) merge(s1) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p')
		reg share_p_`v' CCT1 CCT1xc_r CCT2 CCT2xc_r $vars zcarga2 if sampleflag==1, robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			sum share_p_`v' if CCT3==1 & sampleflag==1
			local m : display %5.1f `r(mean)'			
			outreg, keep( CCT1 CCT1xc_r CCT2 CCT2xc_r) merge(s2) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p') 
		}
	
	outreg using table_c1, replay(s1) replace basefont(fs10) title("Panel A: Main sample")
	outreg using table_c1, replay(s2) addtable basefont(fs10) title("Panel B: Restricted sample")

/* See readme file
* Online appendix Table C2: Benefits Available to Households in the Year Prior to the Follow-Up Survey
	preserve
	use table_c2,clear
	gl benefits "s_bonoyes1 s_bonoyes2 s_bonoyes3 s_bonoyes4 s_bonoyes5 s_bonoyes7 s_exposure1 s_exposure2 s_exposure3 s_exposure4 s_exposure5 s_exposure6 s_exposure7 s_exposure8 s_exposure9 s_exposure10 s_exposure11 s_exposure12 s_exposure13"
	order $benefits treatment village 
	bys treatment: outreg2 using table_c2,sum(log) eqkeep(mean N) replace
	foreach v in $benefits {
		reg `v' treatment,cluster(village)
		}
	restore
*/
	
* Online appendix Table C3: Effects on voter registration in the 2013 presidential election
	gl type "carga"
	outreg,clear(s1)
	outreg,clear(s2)
		reg zcarga CCT1 CCT2 , robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			sum carga if CCT3==1 
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s1) se starlevels(10 5 1) starloc(1) bdec(3) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p')
		reg zcarga CCT1 CCT2 $vars , robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			sum carga if CCT3==1
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s1) se starlevels(10 5 1) starloc(1) bdec(3) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p')
		reg zcarga CCT1 CCT2 if sampleflag==1 , robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			sum carga if CCT3==1 & sampleflag==1
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s2) se starlevels(10 5 1) starloc(1) bdec(3) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p') 
		reg zcarga CCT1 CCT2 $vars if sampleflag==1, robust
			test CCT1=CCT2
			local p : display %4.2f r(p)
			sum carga if CCT3==1 & sampleflag==1
			local m : display %5.1f `r(mean)'			
			outreg, keep(CCT1 CCT2) merge(s2) se starlevels(10 5 1) starloc(1) bdec(3) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m'\"p-value (CCT1=CCT2)",`p') 
		
	outreg using table_c3, replay(s1) replace basefont(fs10) title("Panel A: Main sample")
	outreg using table_c3, replay(s2) addtable basefont(fs10) title("Panel B: Restricted sample")

* Online appendix Table D1: Baseline characteristics of municipalities in PRAF-II sample
	use prafii,clear
	preserve
	gl vars "share_pn_1997 share_pl_1997 female age lenca school literate work dirtfloor pipedwater electriclight sewerseptic"
	keep $vars cct
	order $vars cct
	bys cct: outreg2 using table_d1,sum(log) eqkeep(mean sd N) replace
	restore

	* p-values
	foreach v in $vars {
		reg `v' cct,robust
		}

	foreach v in $vars {
		display "`v'"
		ksmirnov `v' ,by(cct)
		}

* Online appendix Table D2: Effects of PRAF-II on the 2001 presidential election
	gl type "share_participation share_pl share_pn"
	outreg,clear(s1)
	outreg,clear(s2)
	foreach v in $type {
		reg `v' cct i.block, robust
			sum `v' if cct==0 
			local m : display %5.1f `r(mean)'			
			outreg, keep(cct) merge(s1) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m')
		reg `v' cct i.block $vars, robust
			sum `v' if cct==0 
			local m : display %5.1f `r(mean)'			
			outreg, keep(cct) merge(s1) se starlevels(10 5 1) starloc(1) bdec(2) summstat(r2_a \ N) summtitle("Adjusted R2" \ "N") addrows("CCT3 mean",`m')
			}
	outreg using table_d2, replay(s1) replace basefont(fs10) landscape
	
exit
